@@ -70,6 +70,7 @@ extern int unformatted_history;
 string custom_title;
 extern string custom_angle_unit;
 extern EvaluationOptions evalops;
+extern int enable_tooltips;
 
 MathFunction *f_answer;
 MathFunction *f_expression;
@@ -106,18 +107,17 @@ gboolean create_menus_etc(gpointer) {
 
 	test_border();
 
+	generate_units_tree_struct();
+	update_unit_selector_tree();
+	generate_functions_tree_struct();
+	generate_variables_tree_struct();
+
 	//create button menus after definitions have been loaded
 	block_expression_execution++;
 	create_button_menus();
 	block_expression_execution--;
 
 	//create dynamic menus
-	generate_units_tree_struct();
-
-	update_unit_selector_tree();
-
-	generate_functions_tree_struct();
-	generate_variables_tree_struct();
 	create_fmenu();
 	create_vmenu();
 	create_umenu();
@@ -137,6 +137,9 @@ gboolean create_menus_etc(gpointer) {
 		unit_inserted(u);
 	}
 
+	if(!enable_tooltips) set_tooltips_enabled(GTK_WIDGET(gtk_builder_get_object(main_builder, "main_window")), FALSE);
+	else if(enable_tooltips > 1) set_tooltips_enabled(GTK_WIDGET(gtk_builder_get_object(main_builder, "box_tabs")), FALSE);
+
 	update_completion();
 	
 	unblock_completion();
@@ -245,7 +248,7 @@ void create_application(GtkApplication *app) {
 		vans[3]->addName(ans_str + "4");
 		vans[4]->addName(ans_str + "5");
 	}
-	v_memory = new KnownVariable(CALCULATOR->temporaryCategory(), "", m_zero, _("Memory"), true, true);
+	v_memory = new KnownVariable(CALCULATOR->temporaryCategory(), "", m_zero, _("Memory"), false, true);
 	ExpressionName ename;
 	ename.name = "MR";
 	ename.case_sensitive = true;
@@ -266,6 +269,7 @@ void create_application(GtkApplication *app) {
 
 	//load local definitions
 	CALCULATOR->loadLocalDefinitions();
+	remove_old_my_variables_category();
 
 	if(!custom_angle_unit.empty()) {
 		CALCULATOR->setCustomAngleUnit(CALCULATOR->getActiveUnit(custom_angle_unit));
